@@ -3,7 +3,7 @@ import sys
 
 from ptera import Probe
 
-from .analyze import viz
+from .analyze import explore
 from .debug import SnekTalkDb
 from .evaluator import Evaluator
 from .lib import inject, snekprint as print
