@@ -1,6 +1,7 @@
 import os
 from itertools import count
 from types import FunctionType, MethodType
+from typing import Union
 
 from hrepr import H, hjson, hrepr
 
@@ -16,7 +17,7 @@ _count = count()
 
 
 @hjson.dump.variant
-def _sktk_hjson(self, fn: (MethodType, FunctionType)):
+def _sktk_hjson(self, fn: Union[MethodType, FunctionType]):
     method_id = callback_registry.register(fn)
     return f"$$SKTK({method_id})"
 
@@ -89,12 +90,45 @@ def mod(cls):
 
 def pastevar(obj):
     sess = current_session()
-    sess.queue(command="pastevar", value=sess.getvar(obj))
+    sess.queue(command="pastecode", value=sess.getvar(obj))
 
 
-def pastecode(code):
+def pastecode(code, vars={}):
     sess = current_session()
-    sess.queue(command="pastevar", value=code)
+    ev = sess.active_evaluator()
+    if ev is not None:
+        for var, (expected, generate) in vars.items():
+            if ev.get_globals().get(var, None) is not expected:
+                code = f"{generate}\n{code}"
+    sess.queue(command="pastecode", value=code)
+
+
+def newvar(prefix):
+    sess = current_session()
+    ev = sess.active_evaluator()
+    name = prefix
+    if ev is not None:
+        glb = ev.get_globals()
+        i = 2
+        while name in glb:
+            name = f"{prefix}{i}"
+            i += 1
+        glb[name] = None
+    return name
+
+
+def findvar(value, prefix="_"):
+    sess = current_session()
+    ev = sess.active_evaluator()
+    if ev is not None:
+        glb = ev.get_globals()
+        for k, v in glb.items():
+            if v is value:
+                return k
+        name = newvar(prefix)
+        glb[name] = value
+        return name
+    return None
 
 
 def _default_click(obj, evt):
